==> Subsurface-4.8.2.tgz: Subsurface-4.8.2/desktop-widgets/groupedlineedit.h <==
// SPDX-License-Identifier: GPL-2.0
/*
 * Copyright (c) 2013 Maximilian Güntner <maximilian.guentner@gmail.com>
 *
 * This file is subject to the terms and conditions of version 2 of
 * the GNU General Public License.  See the file gpl-2.0.txt in the main
 * directory of this archive for more details.
 *
 * Original License:
 *
 * This file is part of the Nepomuk widgets collection
 *  Copyright (c) 2013 Denis Steckelmacher <steckdenis@yahoo.fr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License version 2.1 as published by the Free Software Foundation,
 * or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef GROUPEDLINEEDIT_H
#define GROUPEDLINEEDIT_H

#include <QPlainTextEdit>
#include <QStringList>

class GroupedLineEdit : public QPlainTextEdit {
	Q_OBJECT

public:
	explicit GroupedLineEdit(QWidget *parent = 0);
	~GroupedLineEdit();

	QString text() const;

	int cursorPosition() const;
	void setCursorPosition(int position);
	void setText(const QString &text);
	void clear();
	void selectAll();

	void removeAllBlocks();
	void addBlock(int start, int end);
	QStringList getBlockStringList();

	void addColor(QColor color);

	QSize sizeHint() const;
	QSize minimumSizeHint() const;

signals:
	void editingFinished();

protected:
	void paintEvent(QPaintEvent *e);
	void keyPressEvent(QKeyEvent *e);

private:
	struct Private;
	Private *d;
};
#endif // GROUPEDLINEEDIT_H

==> Subsurface-4.9.3.tgz: Subsurface-4.9.3/desktop-widgets/groupedlineedit.h <==
// SPDX-License-Identifier: GPL-2.0
/*
 * Copyright (c) 2013 Maximilian Güntner <maximilian.guentner@gmail.com>
 *
 * This file is subject to the terms and conditions of version 2 of
 * the GNU General Public License.  See the file gpl-2.0.txt in the main
 * directory of this archive for more details.
 *
 * Original License:
 *
 * This file is part of the Nepomuk widgets collection
 *  Copyright (c) 2013 Denis Steckelmacher <steckdenis@yahoo.fr>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License version 2.1 as published by the Free Software Foundation,
 * or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 *
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef GROUPEDLINEEDIT_H
#define GROUPEDLINEEDIT_H

#include <QPlainTextEdit>
#include <QStringList>

class GroupedLineEdit : public QPlainTextEdit {
	Q_OBJECT

public:
	explicit GroupedLineEdit(QWidget *parent = 0);
	~GroupedLineEdit();

	QString text() const;

	int cursorPosition() const;
	void setCursorPosition(int position);
	void setText(const QString &text);
	void clear();
	void selectAll();

	void removeAllBlocks();
	void addBlock(int start, int end);
	QStringList getBlockStringList();

	void addColor(QColor color);

	QSize sizeHint() const override;
	QSize minimumSizeHint() const override;

signals:
	void editingFinished();

protected:
	void paintEvent(QPaintEvent *e) override;
	void keyPressEvent(QKeyEvent *e) override;

private:
	struct Private;
	Private *d;
};
#endif // GROUPEDLINEEDIT_H
